pub struct Advance {
pub wrapped: bool,
pub finished: bool,
}Expand description
What one Transport::advance did.
Fields
wrapped: boolThe playhead wrapped at the loop end this call.
finished: boolThe playhead reached the end with no loop (the transport is now Stopped at the last frame).